package com.chinaitop.depot.fumigation.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.fumigation.model.*;
import com.chinaitop.depot.fumigation.service.FumigationForRecordService;
import com.chinaitop.depot.fumigation.service.FumigationPlanService;
import com.chinaitop.depot.fumigation.service.PesticidePlanService;
import com.chinaitop.depot.utils.HttpUtil;
import com.chinaitop.depot.utils.JsonToObjectUtils;
import com.chinaitop.depot.utils.ParameterUtil;
import com.fasterxml.jackson.databind.JavaType;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.MediaType;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @author lvzhikai
 * @description: 熏蒸作业记录
 * @create 2019-1-14 10:57
 */
@RestController
@RequestMapping(value = "/storage/fumigationFroRecord")
@Api(value = "FumigationFroRecordController", description = "熏蒸备注类")
@Slf4j
@SuppressWarnings("all")
public class FumigationForRecordController {

    @Resource
    private FumigationForRecordService fumigationFroRecordService;

    @Resource
    private FumigationPlanService fumigationPlanService;

    @Resource
    private PesticidePlanService pesticidePlanService;


    // 获取ip地址
    @Value("${reportUrl}")
    private String reportPath;
    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationForRecordList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸备案列表", notes = "熏蒸备案列表，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "searchStartDate", value = "申请开始时间", paramType = "query"),
            @ApiImplicitParam(name = "searchEndDate", value = "申请结束时间", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query")
    })
    public PageInfo<TFumigationForrecord> getFumigationForRecordList(Integer pageNum, Integer pageSize, String searchStartDate, String searchEndDate, Integer houseId, Integer orgId) throws Exception {

        List<TFumigationForrecord> list = null;

        TFumigationForrecordExample example = new TFumigationForrecordExample();
        example.setOrderByClause(" create_time desc");
        TFumigationForrecordExample.Criteria criteria = example.createCriteria();
        criteria.andOrgIdEqualTo(orgId);
        criteria.andDeleteStateEqualTo("1");

        if (ParameterUtil.isnotnull(searchStartDate)) {
            searchStartDate = searchStartDate+" 00:00:00";
            criteria.andCreateTimeGreaterThanOrEqualTo(ParameterUtil.string2datetime(searchStartDate));
        }

        if (ParameterUtil.isnotnull(searchEndDate)) {
            searchEndDate = searchEndDate+" 23:59:59";
            criteria.andCreateTimeLessThanOrEqualTo(ParameterUtil.string2datetime(searchEndDate));
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        list = fumigationFroRecordService.getList(example);
        PageInfo<TFumigationForrecord> pageInfo = new PageInfo<TFumigationForrecord>(list);

        return pageInfo;
    }

    /**
     * 列表
     * @param pageNum
     * @param pageSize
     * @param houseId
     * @param orgId
     * @return
     */
    @RequestMapping(value = "/getFumigationPlanList", method = RequestMethod.GET)
    @ApiOperation(value = "熏蒸列表", notes = "熏蒸信息列表(新增作业过程、作业过程时用)，支持分页")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "houseId", value = "仓房Id", paramType = "query"),
            @ApiImplicitParam(name = "orgId", value = "组织机构编号", paramType = "query"),
            @ApiImplicitParam(name = "queryType", value = "查询状态", paramType = "query")
    })
    public PageInfo<TFumigationForrecord> getFumigationPlanList(Integer pageNum, Integer pageSize, Integer houseId, String createTime, Integer orgId, String queryType) {
        TFumigationForrecordExample example = new TFumigationForrecordExample();
        example.setOrderByClause(" create_time desc");
        TFumigationForrecordExample.Criteria criteria = example.createCriteria();

        Map<String,Object> map = new HashMap<>();

        if (ParameterUtil.isnotnull(houseId)) {//仓房查询
            criteria.andHouseIdEqualTo(houseId);
        }

        if (ParameterUtil.isnotnull(createTime)) {//归档用
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            Date date = null;
            try {
                date = dateFormat.parse(createTime);
            } catch (ParseException e) {
                e.printStackTrace();
            }
            criteria.andCreateTimeLessThanOrEqualTo(date);
        }

        if (ParameterUtil.isnotnull(orgId)) {//粮库查询
            criteria.andOrgIdEqualTo(orgId);
        }

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }

        //施药数据。过程数据。善后数据。备案数据
        if(ParameterUtil.isequal(queryType,"XZ") || ParameterUtil.isequal(queryType,"GC")){//新增、过程
            criteria.andStateEqualTo(8);
        }else if(ParameterUtil.isequal(queryType,"SH")){//善后
            criteria.andStateEqualTo(9);
        }else if(ParameterUtil.isequal(queryType,"BA")){//备案
            criteria.andStateEqualTo(5);
        }

        criteria.andDeleteStateEqualTo("1");

        List<TFumigationForrecord> list = fumigationFroRecordService.getList(example);
        PageInfo<TFumigationForrecord> pageInfo = new PageInfo<TFumigationForrecord>(list);
        return pageInfo;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFroRecordDeatil", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id集合查询熏蒸备案数据", notes = "根据熏蒸备案id集合查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getFroRecordDeatil(String planIds) {
        Map<String, Object> modelMap = new HashMap<String, Object>();

        if (planIds != null) {
            String storehouseNames = "";
            Map<String, Object> map = new HashMap<String, Object>();
            map.put("planIds",planIds.split(","));
            List<Map<String, Object>> forRecordList = fumigationFroRecordService.getFumigationDateByIds(map);
            for (Map<String, Object> forRecord:forRecordList) {
                storehouseNames += forRecord.get("storehouse_name") + ",";
            }
            modelMap.put("fumigationEdit",ParameterUtil.slashCapitals(forRecordList));//熏蒸数据
            modelMap.put("storehouseNames",storehouseNames.substring(0,storehouseNames.length()-1));//仓房名称集合--熏蒸作业地点
        }

        return modelMap;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getFroRecordById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸备案数据", notes = "根据熏蒸备案id查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecordId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getFroRecordById(String forRecordId){
        Map<String, Object> modelMap = new HashMap<String, Object>();

        TFumigationForrecord tFumigationForrecord = null;

        try {
            if (forRecordId != null) {
                //获取备案主表数据
                tFumigationForrecord = fumigationFroRecordService.getById(forRecordId);
                modelMap.put("forRecordData",tFumigationForrecord);//熏蒸备案主表数据

                //获取施药人员数据
                TFumigationPersonnelExample tFumigationPersonnelExample = new TFumigationPersonnelExample();
                TFumigationPersonnelExample.Criteria criteria = tFumigationPersonnelExample.createCriteria();
                criteria.andForrecordIdEqualTo(forRecordId);
                List<TFumigationPersonnel> personnelList= fumigationFroRecordService.getPersonnelData(tFumigationPersonnelExample);
                modelMap.put("personnelList",personnelList);//熏蒸施药人员数据
            }

        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

        return modelMap;
    }

    /**
     * 根据id查询熏蒸备案
     * @param id 主键id
     * @return
     */
    @RequestMapping(value="/getInfo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="根据熏蒸备案id查询熏蒸备案数据", notes = "根据熏蒸备案id查询熏蒸备案数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecordId", value = "主键id", paramType = "query")
    })
    public Map<String, Object> getInfo(String forRecordId){
        Map<String, Object> modelMap = new HashMap<String, Object>();

        try {
            TFumigationForrecord tFumigationForrecord = fumigationFroRecordService.getById(forRecordId);
            if (forRecordId != null) {
                modelMap.put("record",tFumigationForrecord);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }

        return modelMap;
    }

    /**
     * 保存熏蒸备案信息
     * @param fumigation
     * @return
     */
    @RequestMapping(value="/saveFumigationForRecordDate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸备案信息", notes = "保存熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "备案备案数据", paramType = "form"),
            @ApiImplicitParam(name = "addedDetail", value = "备案熏蒸人数集合", paramType = "form"),
            @ApiImplicitParam(name = "fumigation", value = "熏蒸数据集合", paramType = "form"),
            @ApiImplicitParam(name = "stateType", value = "保存状态，是提交还是保存", paramType = "form")

    })
    public Map<String, Object> saveFumigationForRecordDate(String forRecord, String addedDetail,String fumigation,String stateType) throws Exception {
        if(ParameterUtil.isequal(stateType,"getSubmit")){
            stateType = "7";
        }else{
            stateType = "6";
        }

        Map<String, Object> modelMap = new HashMap<String, Object>();
        // JSON字符串转对象
        String uuid = ParameterUtil.getCode();
        TFumigationForrecord tFumigationForrecord = (TFumigationForrecord) JsonToObjectUtils.jsonToObject(forRecord,"com.chinaitop.depot.fumigation.model.TFumigationForrecord");
        if (tFumigationForrecord.getId() == null) {
            //新增熏蒸备案数据
            tFumigationForrecord.setDeleteState("1");//默认设置删除标志
            tFumigationForrecord.setCreateTime(new Date());//创建时间
            tFumigationForrecord.setId(uuid);
            fumigationFroRecordService.add(tFumigationForrecord);
        } else {
            uuid = tFumigationForrecord.getId();
            tFumigationForrecord.setUpdatetime(new Date());//修改时间
            fumigationFroRecordService.update(tFumigationForrecord);
        }

        //熏蒸人员字段
        String[] personnelDates = addedDetail.split("},");
        for (String personnel:personnelDates) {
            TFumigationPersonnel tFumigationPersonnel = (TFumigationPersonnel) JsonToObjectUtils.jsonToObject(personnel + "}", "com.chinaitop.depot.fumigation.model.TFumigationPersonnel");
            if (tFumigationPersonnel.getId() == null) {
                tFumigationPersonnel.setDeleteState("1");//默认设置删除标志
                tFumigationPersonnel.setCreateTime(new Date());//创建时间
                tFumigationPersonnel.setId(ParameterUtil.getCode());
                tFumigationPersonnel.setForrecordId(uuid);
                tFumigationPersonnel.setOrgId(tFumigationForrecord.getOrgId());
                fumigationFroRecordService.addPersonnel(tFumigationPersonnel);
            } else {
                tFumigationPersonnel.setUpdatetime(new Date());//修改时间
                fumigationFroRecordService.updatePersonnel(tFumigationPersonnel);
            }
        }

        //熏蒸信息字段
        String[] fumigationDates = fumigation.split("},");
        Integer c=1;
        for (String fumigations:fumigationDates) {
            JSONObject fumMap = null;
            if(c != fumigationDates.length){
                fumMap = JSON.parseObject(fumigations+"}");
            }else{
                fumMap = JSON.parseObject(fumigations);
            }
            c++;
            //修改熏蒸状态
            TFumigationPlanExample example = new TFumigationPlanExample();
            TFumigationPlanExample.Criteria criteria = example.createCriteria();
            criteria.andIdEqualTo(fumMap.get("planid").toString());

            TFumigationPlan tFumigationPlan = new TFumigationPlan();
            tFumigationPlan.setState(Integer.parseInt(stateType));
            tFumigationPlan.setGrainMoisture(fumMap.get("grainMoisture").toString());
            tFumigationPlan.setStowWay(fumMap.get("stowWay").toString());
            tFumigationPlan.setForRecordId(uuid);
            fumigationPlanService.updateByExample(tFumigationPlan, example);

            //修改熏蒸施药状态
            TFumigationPesticideExample pesticideExample = new TFumigationPesticideExample();
            TFumigationPesticideExample.Criteria pesticideCriteria = pesticideExample.createCriteria();
            pesticideCriteria.andIdEqualTo(fumMap.get("pesticideid").toString());

            TFumigationPesticide tFumigationPesticide = new TFumigationPesticide();
            tFumigationPesticide.setReagentType("3024");
            tFumigationPesticide.setValidity(fumMap.get("validity").toString());
            tFumigationPesticide.setGetNumber(fumMap.get("getNumber").toString());
            tFumigationPesticide.setGetPerson(fumMap.get("getPerson").toString());
            tFumigationPesticide.setGetTime(ParameterUtil.string2datetime(fumMap.get("getTime").toString()));
            pesticidePlanService.updateByExample(tFumigationPesticide, pesticideExample);
        }

        if(ParameterUtil.isequal(stateType,"7")){
            try {
                //如果是提交的话则除了保存还要把数据提交到市级来进行审批
                Map<String, Object> dataMap = fumigationFroRecordService.getFroRecordByIds(uuid);
                String url = reportPath+"/api/cbl-app/cbl/fumigation/insertFumigation";//市级接口
                String strResult = HttpUtil.doPost(url,JSON.toJSONString(dataMap));
            }catch (IOException e) {
                e.printStackTrace();
            } finally {
                modelMap.put("status", "success");
            }
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 删除熏蒸申请信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/removeDetail", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="删除熏蒸备案信息", notes = "删除熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "熏蒸主键集合", paramType = "form"),
            @ApiImplicitParam(name = "forrecordId", value = "主键id", paramType = "form")
    })
    public Map<String, Object> removeDetail(String planIds, String forrecordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();

        //修改熏蒸状态
        TFumigationForrecordExample tFumigationForrecordExample = new TFumigationForrecordExample();
        TFumigationForrecordExample.Criteria criteria = tFumigationForrecordExample.createCriteria();
        criteria.andIdEqualTo(forrecordId);

        TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
        tFumigationForrecord.setDeleteState("0");
        fumigationFroRecordService.updateByExample(tFumigationForrecord, tFumigationForrecordExample);
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 提交熏蒸申请信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getSubmit", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="提交熏蒸备案信息", notes = "提交熏蒸备案信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planIds", value = "熏蒸主键集合", paramType = "form"),
            @ApiImplicitParam(name = "forrecordId", value = "主键id", paramType = "form")
    })
    public Map<String, Object> getSubmit(String planIds, String forrecordId) throws Exception {
        Map<String, Object> modelMap = new HashMap<>();
        if (planIds != null) {
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria criteria = example.createCriteria();
                criteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(7);
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }
        try {
            //如果是提交的话则除了保存还要把数据提交到市级来进行审批
            Map<String, Object> dataMap = fumigationFroRecordService.getFroRecordByIds(forrecordId);
            String url = reportPath+"/api/cbl-app/cbl/fumigation/insertFumigation";//市级接口
            String strResult = HttpUtil.doPost(url,JSON.toJSONString(dataMap));
        }catch (IOException e) {
            e.printStackTrace();
        } finally {
            modelMap.put("status", "success");
        }
        return modelMap;
    }

    /**
     * 提交熏蒸审批信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/getForRecordApproval", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="提交熏蒸备案信息", notes = "提交熏蒸备案信息-市级用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "主键id", paramType = "form")
    })
    public void getForRecordApproval(String forRecord) throws Exception {
        //市级传输过来的审批过后的备案数据
        JSONObject forRecordData = JSONObject.parseObject(forRecord);
        String forrecordId = forRecordData.get("forrecordId").toString();
        Map<String, Object> modelMap = new HashMap<>();
        if (forrecordId != null) {
            //修改熏蒸备案信息
            TFumigationForrecordExample tFumigationForrecordExample = new TFumigationForrecordExample();
            TFumigationForrecordExample.Criteria criteria = tFumigationForrecordExample.createCriteria();
            criteria.andIdEqualTo(forrecordId);

            TFumigationForrecord tFumigationForrecord = new TFumigationForrecord();
            tFumigationForrecord.setOrgansOpinion(forRecordData.get("organsOpinion").toString());
            tFumigationForrecord.setOutPerson(forRecordData.get("outPerson").toString());
            tFumigationForrecord.setOutForrecordTime(ParameterUtil.string2datetime(forRecordData.get("outForrecordTime").toString()));
            fumigationFroRecordService.updateByExample(tFumigationForrecord, tFumigationForrecordExample);

            //获取备案数据
            List<Map<String, Object>> forRecords = fumigationFroRecordService.getFroRecordById(forrecordId);
            String planIds = "";
            for (Map<String, Object> maps:forRecords) {
                planIds+=maps.get("planids")+",";
            }
            planIds = planIds.substring(0,planIds.length()-1);

            //下边获取熏蒸数据
            String[] planId = planIds.split(",");
            for (String id:planId) {
                //修改熏蒸状态
                TFumigationPlanExample example = new TFumigationPlanExample();
                TFumigationPlanExample.Criteria planCriteria = example.createCriteria();
                planCriteria.andIdEqualTo(id);

                TFumigationPlan tFumigationPlan = new TFumigationPlan();
                tFumigationPlan.setState(8);
                fumigationPlanService.updateByExample(tFumigationPlan, example);
            }
        }
    }

    /**
     * 保存熏蒸备案信息
     * @param forrecordId 主键id
     * @return
     * @throws Exception
     */
    @RequestMapping(value="/insertRecord", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value="保存熏蒸信息及备案信息", notes = "保存熏蒸信息及备案信息-市级用")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "forRecord", value = "熏蒸备案基础信息和备案信息", paramType = "form")
    })
    public Map<String, Object> insertRecord(String forRecord) throws Exception {
        log.info("熏蒸申请数据接收如下：");
        log.info(forRecord);
        Map<String, Object> modelMap = new HashMap<>();
        if(StringUtils.isEmpty(forRecord)){
            modelMap.put("msg","所传信息为空，请检查");
            return modelMap;
        }
        JSONObject recordInfo = JSONObject.parseObject(forRecord);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String xzzydh = null;
        String operationSupervisor = null;
        String contactPhone = null;
        String xzzydd = null;
        String lyccdwfzr = null;
        String lyccdw = null;
        String ylccdwlxdh = null;
        String fumigationStart = null;
        String fumigationEnd = null;
        String creater = null;
        String createTime = null;
        String updateTime = null;
        String enterpriseOpinion = null;
        String organsOpinion = null;
        String spsj = null;
        String spr = null;
        String position = null;
        String fhry = null;
        if(recordInfo.get("id")!=null){
            //熏蒸作业单号
            xzzydh = (String)recordInfo.get("id");
        }
        if(recordInfo.get("operationSupervisor")!=null){
            //熏蒸作业制定人
            operationSupervisor = (String)recordInfo.get("operationSupervisor");
        }
       if(recordInfo.get("contactPhone")!=null){
           //联系电话
           contactPhone = (String)recordInfo.get("contactPhone");
       }
       if(recordInfo.get("operationLocaltion")!=null){
           //熏蒸作业地点
           xzzydd=(String)recordInfo.get("operationLocaltion");
       }
       if(recordInfo.get("orgPerson")!=null){
           //熏蒸方案起草人
           lyccdwfzr = (String)recordInfo.get("orgPerson");
       }
       if(recordInfo.get("orgName")!=null){
           //粮油仓储单位
           lyccdw = (String)recordInfo.get("orgName");
       }
       if(recordInfo.get("orgPhone")!=null){
           //粮油仓储单位联系电话
           ylccdwlxdh = (String)recordInfo.get("orgPhone");
       }
       if(recordInfo.get("fumigationStart")!=null){
           //熏蒸开始时间
           fumigationStart=(String)recordInfo.get("fumigationStart");
       }
       if(recordInfo.get("fumigationEnd")!=null){
           //熏蒸结束时间
           fumigationEnd = (String)recordInfo.get("fumigationEnd");
       }
       if(recordInfo.get("creater")!=null){
           //申请人
           creater = (String)recordInfo.get("creater");
       }
       if(recordInfo.get("createTime")!=null){
           //申请时间
           createTime = (String)recordInfo.get("createTime");
       }
       if(recordInfo.get("updateTime")!=null){
           //修改时间
           updateTime = (String)recordInfo.get("updateTime");
       }
       if(recordInfo.get("qyspyj")!=null){
           //申请企业意见
           enterpriseOpinion = (String)recordInfo.get("qyspyj");
       }
       if(recordInfo.get("qlbspyj")!=null){
           //备案机关意见
           organsOpinion = (String)recordInfo.get("qlbspyj");
       }
       if(recordInfo.get("qlbspsj")!=null){
           //审批时间
           spsj = (String)recordInfo.get("qlbspsj");
       }
       if(recordInfo.get("qyfzr")!=null){
           //审批人
           spr =(String)recordInfo.get("qyfzr");
       }
       if(recordInfo.get("position")!=null){
           //职务
           position =(String)recordInfo.get("position");
       }
       if(recordInfo.get("fhry")!=null){
           //防护人员
           fhry =(String)recordInfo.get("fhry");
       }
        if(recordInfo.get("detailVOS")==null){
            modelMap.put("msg","缺少库房信息");
            return modelMap;
        }
        //要熏蒸的仓房集合
        List<Map<String,Object>> details = (List<Map<String,Object>>)recordInfo.get("detailVOS");
        for (Map<String, Object> detail : details) {
            //熏蒸备案表
            TFumigationForrecord fumigationForrecord = new TFumigationForrecord();
            String uuid = ParameterUtil.getCode();
            fumigationForrecord.setFhry(fhry);//防护人员
            fumigationForrecord.setId(uuid);
            //fumigationForrecord.setPosition(position);//职务
            fumigationForrecord.setXzzydh(xzzydh);//熏蒸作业单号
            //fumigationForrecord.setOperationSupervisor(operationSupervisor);//熏蒸作业负责人
            fumigationForrecord.setXzfazd(operationSupervisor);//熏蒸方案制定人
            fumigationForrecord.setXzfaqcr(lyccdwfzr);//熏蒸方案起草人
            fumigationForrecord.setContactPhone(contactPhone);//联系电话
            fumigationForrecord.setXzzydd(xzzydd); //熏蒸作业地点
            //fumigationForrecord.setLyccdwfzr(lyccdwfzr);
            //fumigationForrecord.setLyccdw(lyccdw);
            //fumigationForrecord.setYlccdwlxdh(ylccdwlxdh);
            if(fumigationStart!=null){
                fumigationForrecord.setFumigationStart(format.parse(fumigationStart));//熏蒸开始时间
            }
            if(fumigationEnd!=null){
                fumigationForrecord.setFumigationEnd(format.parse(fumigationEnd));//熏蒸结束时间
            }
            fumigationForrecord.setSqr(creater);//申请人
            if(createTime!=null){
                fumigationForrecord.setCreateTime(format.parse(createTime));//申请时间
            }
            if(updateTime!=null){
                fumigationForrecord.setUpdatetime(format.parse(updateTime));//修改时间
            }
            fumigationForrecord.setEnterpriseOpinion(enterpriseOpinion);//申请企业意见
            fumigationForrecord.setOrgansOpinion(organsOpinion);//备案机关意见
            if(spsj!=null){
                fumigationForrecord.setSpsj(format.parse(spsj));//审批时间
                fumigationForrecord.setOutForrecordTime(format.parse(spsj));//备案时间
            }
            fumigationForrecord.setSpr(spr);//审批人
            fumigationForrecord.setDeleteState("1");//写死为已备案
            fumigationForrecord.setOutPerson(spr);
            String cfdm = null;
            Integer orgId =null;
            Integer houseId =null;
            String cfmc = null;
            BigDecimal lssl = null;
            String lspz = null;
            String lyxz = null;
            String cgxzfs = null;
            String hlxzfs = null;
            Integer xzfs = null;
            String hlxzynhljsjh = null;
            String yjmc = null;
            String jx =null;
            BigDecimal nd =null;
            String syff = null;
            Integer lqsl = null;
            BigDecimal lddwyyl = null;
            BigDecimal kjdwyyl = null;
            BigDecimal zyyl = null;
            String hcjcdh = null;
            BigDecimal lysf = null;
            String dzfs = null;
            String east = null;
            String west = null;
            String south = null;
            String north = null;
            String yjyxq = null;
            String lqr = null;
            String lqsj = null;
            String xzzhr = null;
            Integer xzrs = null;
            String xzczry = null;
            String processingInstructions = null;
            if(detail.get("cfbh")!=null){
                cfdm = (String)detail.get("cfbh");
                Map<String,Integer> info = fumigationFroRecordService.getByCfdm(cfdm);
                if(info!=null){
                    orgId = info.get("orgid");
                    houseId = info.get("houseid");
                }else{
                    modelMap.put("msg","未获取到仓房对应org信息和house信息");
                    return modelMap;
                }
            }
            if(detail.get("cfmc")!=null){
                //仓房名称
                cfmc = (String)detail.get("cfmc");
            }
            if(detail.get("kcsl")!=null){
                //库存数量
                lssl = new BigDecimal(ObjectUtils.toString(detail.get("kcsl")));
            }
            if(detail.get("lspzCode")!=null){
                //粮食品种
                lspz = ObjectUtils.toString(detail.get("lspzCode"));
            }
            if(detail.get("lsxzCode")!=null){
                //粮食性质
                lyxz = ObjectUtils.toString(detail.get("lsxzCode"));
            }
            if(detail.get("convFumigation")!=null){
                //常规熏蒸方式
                cgxzfs = (String)detail.get("convFumigation");
            }
            if(detail.get("recFumigation")!=null){
                //环流熏蒸方式
                hlxzfs = (String)detail.get("recFumigation");
            }
            if(detail.get("xzfs")!=null){
                //熏蒸方式
                xzfs = (Integer)detail.get("xzfs");
            }
            if(detail.get("recIcCombine")!=null){
                //环流熏蒸与内环流技术结合
                hlxzynhljsjh = (String)detail.get("recIcCombine");
            }
            if(detail.get("drugNameCode")!=null){
                //药剂名称
                yjmc = ObjectUtils.toString(detail.get("drugNameCode"));
            }
            if(detail.get("drugTypeCode")!=null){
                //剂型
                jx = ObjectUtils.toString(detail.get("drugTypeCode"));
            }
            if(detail.get("drugConcentration")!=null){
                //浓度
                nd = new BigDecimal(ObjectUtils.toString(detail.get("drugConcentration")));;
            }
            if(detail.get("applicationMethod")!=null){
                //施药方法
                syff = (String)detail.get("applicationMethod");
            }
            if(detail.get("getNumber")!=null){
                //领取数量
                lqsl = (Integer)detail.get("getNumber");
            }
            if(detail.get("grainDosage")!=null){
                //堆粮单位用药量
                lddwyyl = new BigDecimal(ObjectUtils.toString(detail.get("grainDosage")));
            }
            if(detail.get("spaceDosage")!=null){
                //空间单位用药量(g/m3)
                kjdwyyl = new BigDecimal(ObjectUtils.toString(detail.get("spaceDosage")));
            }
            if(detail.get("totalDosage")!=null){
                //总用药量(kg)
                zyyl = new BigDecimal(ObjectUtils.toString(detail.get("totalDosage")));
            }
            if(detail.get("pestNo")!=null){
                //害虫检测单号
                hcjcdh = (String)detail.get("pestNo");
            }
            if(detail.get("lysf")!=null){
                //粮油水分
                lysf =new BigDecimal(ObjectUtils.toString(detail.get("lysf")));
            }
            if(detail.get("dzfs")!=null){
                //堆装方式
                dzfs =(String)detail.get("dzfs");
            }
            if(detail.get("east")!=null){
                //东
                east =(String)detail.get("east");
            }
            if(detail.get("west")!=null){
                //西
                west =(String)detail.get("west");
            }
            if(detail.get("south")!=null){
                //南
                south =(String)detail.get("south");
            }
            if(detail.get("north")!=null){
                //北
                north =(String)detail.get("north");
            }
            if(detail.get("yjyxq")!=null){
                //药剂有效期
                yjyxq =(String)detail.get("yjyxq");
            }
            if(detail.get("lqr")!=null){
                //领取人
                lqr =(String)detail.get("lqr");
            }
            if(detail.get("lqsj")!=null){
                //领取时间
                lqsj =(String)detail.get("lqsj");
            }
            if(detail.get("xzzhr")!=null){
                //熏蒸指挥人
                xzzhr =(String)detail.get("xzzhr");
            }
            if(detail.get("xzrs")!=null){
                //熏蒸人数
                xzrs =(Integer)detail.get("xzrs");
            }
            if(detail.get("xzczry")!=null){
                //熏蒸操作人员
                xzczry =(String)detail.get("xzczry");
            }
            if(detail.get("processingInstructions")!=null){
                //包装物及药剂残渣处理说明
                processingInstructions =(String)detail.get("processingInstructions");
            }
            fumigationForrecord.setLysf(lysf);//粮油水分
            fumigationForrecord.setDzfs(dzfs);//堆装方式
            //fumigationForrecord.setEast(east);//东
            //fumigationForrecord.setWest(west);//西
            //fumigationForrecord.setSouth(south);//南
            fumigationForrecord.setStowWay(dzfs);//堆装方式
            fumigationForrecord.setSyff(syff);//施药方式
            //fumigationForrecord.setNorth(north);//北
            if(yjyxq!=null){
                //药剂有效期
                fumigationForrecord.setYjyxq(format.parse(yjyxq));
            }
            fumigationForrecord.setLqr(lqr);//领取人
            if(lqsj!=null){
                fumigationForrecord.setLqsj(format.parse(lqsj));//领取时间
            }
            fumigationForrecord.setXzzhr(xzzhr);//熏蒸指挥人
            fumigationForrecord.setXzrs(xzrs);//熏蒸人数
            fumigationForrecord.setXzczry(xzczry);//熏蒸操作人员
            fumigationForrecord.setProcessingInstructions(processingInstructions);//包装物及药剂残渣处理说明
            if(detail.get("pestVOS")!=null){
                if(detail.get("pestVOS")!=null){
                    List<Map<String,Object>> pest =  (List<Map<String,Object>>)detail.get("pestVOS");
                    if(!CollectionUtils.isEmpty(pest)){
                        String zyhc = "";
                        String ckmd = "";
                        for (Map<String, Object> stringObjectMap : pest) {
                            TFumigationPesticide pesticide = new TFumigationPesticide();
                            pesticide.setId(ParameterUtil.getCode());
                            pesticide.setRecordId(uuid);
                            pesticide.setUseDrugType(syff);
                            pesticide.setReagentType(jx);
                            pesticide.setCreateTime(new Date());
                            pesticide.setDrugPurity(nd.toString());
                            if(stringObjectMap.get("hczlCode") !=null){
                                zyhc +=ObjectUtils.toString(stringObjectMap.get("hczlCode"))+"#";//主要害虫
                                pesticide.setMajorInsectPests(Integer.valueOf(ObjectUtils.toString(stringObjectMap.get("hczlCode"))));//主要害虫
                            }
                            if(stringObjectMap.get("density") !=null){
                                ckmd += (String)stringObjectMap.get("density") + "|";//虫口密度
                                pesticide.setInsectDensity((String)stringObjectMap.get("density"));//虫口密度
                            }
                            if(yjmc!=null){
                                pesticide.setDrugName(Integer.valueOf(yjmc));//药剂名称
                            }
                            if(stringObjectMap.get("discoveryTime")!=null){
                                pesticide.setInsectProductTime(format.parse((String)stringObjectMap.get("discoveryTime")));//发现虫害日期
                            }
                            if(stringObjectMap.get("happenPosition")!=null){
                                pesticide.setOccurrencePlace((String)stringObjectMap.get("happenPosition"));//发生部位
                            }
                            if(stringObjectMap.get("pestResistance")!=null){
                                pesticide.setDrugResistance((String)stringObjectMap.get("pestResistance"));//害虫抗药性分析
                            }
                            if(stringObjectMap.get("sealType")!=null){
                                pesticide.setSealType((String)stringObjectMap.get("sealType"));//密闭方法
                            }
                            pesticidePlanService.add(pesticide);
                        }
                        zyhc = zyhc.substring(0,zyhc.lastIndexOf("#"));
                        ckmd = ckmd.substring(0,ckmd.lastIndexOf("|"));
                        fumigationForrecord.setZyhc(zyhc);//主要害虫
                        fumigationForrecord.setCkmd(ckmd);//虫口密度
                    }
                }
            }
            if(detail.get("fumigationPersonnelList")!=null){
                List<Map<String,String>> person  =  (List<Map<String,String>>)detail.get("fumigationPersonnelList");
                if(!CollectionUtils.isEmpty(person)){
                    for (Map<String, String> stringObjectMap : person) {
                        TFumigationPersonnel personnel = new TFumigationPersonnel();
                        personnel.setDeleteState("1");//默认设置删除标志
                        personnel.setCreateTime(new Date());//创建时间
                        personnel.setId(ParameterUtil.getCode());
                        personnel.setForrecordId(uuid);
                        personnel.setOrgId(orgId);

                        if(stringObjectMap.get("personnelName") !=null){
                            //熏蒸人员姓名
                            personnel.setPersonnelName(stringObjectMap.get("personnelName"));
                        }
                        if(stringObjectMap.get("professionalQualification") !=null){
                            //职业资格
                            personnel.setProfessionalQualification(stringObjectMap.get("professionalQualification"));
                        }
                        if(stringObjectMap.get("physicalCondition") !=null){
                            //身体状况(施药资质审核	)
                            personnel.setPhysicalCondition(stringObjectMap.get("physicalCondition"));
                        }
                        if(stringObjectMap.get("workTask") !=null){
                            //工作任务
                            personnel.setWorkTask(stringObjectMap.get("workTask"));
                        }
                        if(stringObjectMap.get("outside") !=null){
                            //是否为外请
                            personnel.setOutside(stringObjectMap.get("outside").equals("1")?"是":"否");
                        }
                        fumigationFroRecordService.addPersonnel(personnel);
                    }
                }
            }
            fumigationForrecord.setCfdm(cfdm);//仓房代码
            fumigationForrecord.setCfmc(cfmc);//仓房名称
            fumigationForrecord.setHouseId(houseId);//仓房id
            fumigationForrecord.setOrgId(orgId);//组织机构ID
            fumigationForrecord.setLssl(lssl);//粮食数量
            fumigationForrecord.setLspz(lspz);//粮食品种
            fumigationForrecord.setLyxz(lyxz);//粮油性质
            fumigationForrecord.setCgxzfs(cgxzfs);//常规熏蒸方式
            fumigationForrecord.setHlxzfs(hlxzfs);//环流熏蒸方式
            fumigationForrecord.setXzfs(xzfs);//熏蒸方式
            fumigationForrecord.setHlxzynhljsjh(hlxzynhljsjh);//环流熏蒸与内环流技术结合
            fumigationForrecord.setYjmc(yjmc);//药剂名称
            fumigationForrecord.setJx(jx);//药剂剂型
            fumigationForrecord.setNd(nd);//药剂浓度
            fumigationForrecord.setSyff(syff);//施药方式
            if(lqsl!=null){
                //领取数量
                fumigationForrecord.setLqsl(new BigDecimal(lqsl));//领取数量
            }
            fumigationForrecord.setLddwyyl(lddwyyl);//粮堆单位用药量
            fumigationForrecord.setKjdwyyl(kjdwyyl);//空间单位用药量
            fumigationForrecord.setZyyl(zyyl);//总用药量
            fumigationForrecord.setHcjcdh(hcjcdh);//害虫检测单号
            fumigationForrecord.setState(8);//写死为已备案
            fumigationFroRecordService.add(fumigationForrecord);
        }
        modelMap.put("msg","新增成功");
        return modelMap;
        //市级传输过来的审批过后的备案数据
        /*Map<String, Object> modelMap = new HashMap<>();*/
        // JSON字符串转对象
       /* ObjectMapper mapper = new ObjectMapper();
        JavaType javaType = mapper.getTypeFactory().constructParametricType(ArrayList.class,TFumigationForrecord.class);
        List<TFumigationForrecord> tFumigationForrecordList = mapper.readValue(forRecord, javaType);*/
        /*if(!CollectionUtils.isEmpty(tFumigationForrecordList)){
            for (TFumigationForrecord tFumigationForrecord : tFumigationForrecordList) {
                String uuid = ParameterUtil.getCode();
                tFumigationForrecord.setId(uuid);
                tFumigationForrecord.setState(8);
                tFumigationForrecord.setCreateTime(new Date());
                fumigationFroRecordService.add(tFumigationForrecord);
                if(CollectionUtils.isEmpty(tFumigationForrecord.getFumigationPersonnelList())){
                    for (TFumigationPersonnel tFumigationPersonne : tFumigationForrecord.getFumigationPersonnelList()) {
                        tFumigationPersonne.setDeleteState("1");//默认设置删除标志
                        tFumigationPersonne.setCreateTime(new Date());//创建时间
                        tFumigationPersonne.setId(ParameterUtil.getCode());
                        tFumigationPersonne.setForrecordId(uuid);
                        tFumigationPersonne.setOrgId(tFumigationForrecord.getOrgId());
                        fumigationFroRecordService.addPersonnel(tFumigationPersonne);
                    }

                }
            }
        }*/

    }
}