package com.chinaitop.depot.risk.service.impl;

import com.chinaitop.depot.risk.mapper.StorageSafeManageMapper;
import com.chinaitop.depot.risk.model.StorageSafeManage;
import com.chinaitop.depot.risk.model.StorageSafeManageExample;
import com.chinaitop.depot.risk.model.StorageSafeManageWithBLOBs;
import com.chinaitop.depot.risk.service.StorageSafeManageService;
import com.chinaitop.depot.utils.ParameterUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.UUID;

@Service
public class StorageSafeManageServiceImpl implements StorageSafeManageService {

    @Resource
    private StorageSafeManageMapper storageSafeManageMapper;

    @Override
    public List<StorageSafeManageWithBLOBs> findbyConditions(Integer orgId, Integer fxlx, Integer fxfj) throws Exception {

        StorageSafeManageExample example = new StorageSafeManageExample();
        StorageSafeManageExample.Criteria criteria = example.createCriteria();
        if (null != orgId)
            criteria.andOrgIdEqualTo(orgId);
        if (null != fxlx)
            criteria.andFxlxEqualTo(fxlx);
        if (null != fxfj)
            criteria.andFxfjEqualTo(fxfj);
        example.setOrderByClause(" createtime desc");
        List<StorageSafeManageWithBLOBs> list = storageSafeManageMapper.selectByExampleWithBLOBs(example);

        return list;
    }

    @Override
    public StorageSafeManageWithBLOBs findbyPKConditions(String id) throws Exception {

        StorageSafeManageWithBLOBs storageSafeManage = storageSafeManageMapper.selectByPrimaryKey(id);
        return storageSafeManage;
    }

    @Override
    public void saveAndUpdate(StorageSafeManageWithBLOBs storageSafeManage) throws Exception {

        //获取当前时间：yyyy-MM-dd HH:mm:ss
        String date = ParameterUtil.getSysDateTime();
        
        //生成风险点编码
        Map<String, Object> map = storageSafeManageMapper.getBasicEnumObj(storageSafeManage.getCounty());
        String xzqhdm = map.get("gbcode").toString();
        storageSafeManage.setFxdbm(getFxdbm(xzqhdm, date));
        if (StringUtils.isBlank(storageSafeManage.getId())) {
            String uuid = UUID.randomUUID().toString().replace("-", "");
            storageSafeManage.setId(uuid);
            storageSafeManage.setCreatetime(ParameterUtil.string2datetime(date));
            storageSafeManage.setCzbz("i");
            storageSafeManageMapper.insert(storageSafeManage);
        } else {
            storageSafeManage.setCzbz("u");
            storageSafeManage.setZhgxsj(date);
            storageSafeManageMapper.updateByPrimaryKeyWithBLOBs(storageSafeManage);
        }
    }

    @Override
    public void deleteById(String id) throws Exception {
        storageSafeManageMapper.deleteByPrimaryKey(id);
    }

    /**
     * 生成风险点编码
     * 6位行政区划代码+8位风险识别日期（YYYYMMDD）+4位风险顺序号（如:0001）
     * @param xzqhdm 行政区划代码
     * @param date 当前时间格式：yyyy-MM-dd HH:mm:ss
     * @return
     */
    private String getFxdbm(String xzqhdm, String date) {
        String fxdbm = "";


        StringBuffer sbf = new StringBuffer(100);
        //6位行政区划代码
        sbf.append(xzqhdm);
        //8位风险识别日期（YYYYMMDD）
        sbf.append(date.substring(0, 10).replace("-", "").trim());
        //4位风险顺序号(为避免重复，这里取分和秒)
        sbf.append(date.substring(date.length()-5, date.length()).replace(":", "").trim());

        fxdbm = sbf.toString();

        return fxdbm;
    }
}
